/*
 * @author Ben Mazyopa email: ben.mazyopa@cbu.ac.zm The code is the property of
 * Ben Mazyopa DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * Copyright 2009, Ben Mazyopa. All rights reserved. The contents of this file
 * are subject to the terms of either the GNU General Public License Version 2
 * only ("GPL") or the Common Development and Distribution License("CDDL")
 * (collectively, the "License"). You may not use this file except in compliance
 * with the License
 */
package org.idc.upload;

import javax.el.ValueExpression;
import javax.faces.FacesException;
import javax.faces.component.EditableValueHolder;
import javax.faces.component.FacesComponent;
import javax.faces.component.UIComponent;
import javax.faces.component.UIInput;
import javax.faces.component.behavior.*;
import javax.faces.context.ExternalContext;
import javax.faces.context.ResponseWriter;
import javax.faces.context.FacesContext;
import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import org.apache.commons.fileupload.FileItem;

import java.io.File;
import java.io.IOException;
import java.util.Collection;
import java.util.List;
import java.util.Map;

@FacesComponent(value = "fileUpload")
public class UploadRenderer extends UIInput implements ClientBehaviorHolder
  {

@Override
public String getFamily()
  {
   return "fileUpload";
  }

@Override
public void encodeEnd(FacesContext context) throws IOException
  {
   ResponseWriter responseWriter = context.getResponseWriter();
   String clientId = getClientId(context);

   responseWriter.startElement("input",null);
   responseWriter.writeAttribute("id",clientId,"id");
   responseWriter.writeAttribute("name",clientId,"clientId");
   responseWriter.writeAttribute("type","file","file");

   // add a style class if the styleClass attribute exist
   UIComponent component = getCurrentComponent(context);
   String styleClass = (String)component.getAttributes().get("styleClass");
   if (styleClass != null) responseWriter.writeAttribute("class",styleClass,"styleClass");

   // add a style if the style attribute exist
   String style = (String)component.getAttributes().get("style");
   if (style != null) responseWriter.writeAttribute("style",style,"style");

   responseWriter.endElement("input");
   responseWriter.flush();
  }

@Override
public void decode(FacesContext context)
  {
   ExternalContext external = context.getExternalContext();
   HttpServletRequest request = (HttpServletRequest)external.getRequest();
   String clientId = getClientId(context);
   FileItem item = (FileItem)request.getAttribute(clientId);
   String clientFileName = item.getName();
   
   // remove potential path information from filename
   if (clientFileName.indexOf('/') > 0) clientFileName = clientFileName.substring(clientFileName.lastIndexOf('/'));
   if (clientFileName.indexOf('\\') > 0) clientFileName = clientFileName.substring(clientFileName.lastIndexOf('\\'));

   ValueExpression valueExpr = getValueExpression("value");
   
   if (valueExpr != null)
     {
      UIComponent component = getCurrentComponent(context);
      
      if (item.getSize() > 0)
        {
         String target = getAttributes().get("target").toString();
         String realPath = getServletRealPath(external,target);
        
         
         String longFileName = getLongFileName(realPath,clientFileName);
         String shortFileName = target + "/" + clientFileName;
         
         // if the target location ends with the forward slash, just join the
         // target and the filename
         if (target.endsWith("/")) shortFileName = target + clientFileName;
         
         ((EditableValueHolder)component).setSubmittedValue(new UploadedFile(item,longFileName,shortFileName));
        }
      else
        {
         ((EditableValueHolder)component).setSubmittedValue(new UploadedFile());
        }
      ((EditableValueHolder)component).setValid(true);
     }
   
   Object target = getAttributes().get("target");
   
   if (target != null)
     {
      String realPath = getServletRealPath(external,target.toString());
      File file = new File(getLongFileName(realPath,clientFileName));
      
      try
        {
         if (item.getSize() > 0 && clientFileName.length() > 0) item.write(file);
        }
      catch (Exception ex)
        {
         throw new FacesException(ex);
        }
     }
  }

private String getLongFileName(String path,String fileName)
  {
   return path + fileName;
  }

public Collection<String> getEventNames()
  {
   return null;
  }

public String getDefaultEventName()
  {
   return "";
  }

public void addClientBehavior(String s,ClientBehavior c)
  {
  }

public Map<String,List<ClientBehavior>> getClientBehaviors()
  {
   return null;
  }

private String getServletRealPath(ExternalContext external,String target)
  {
   ServletContext servletContext = (ServletContext)external.getContext();
   String realPath = servletContext.getRealPath(target.toString());
   
   if (!realPath.endsWith("/")) realPath += "/";
   
   return realPath;
  }
}