/*
 * @author Ben Mazyopa email: ben.mazyopa@cbu.ac.zm DO NOT ALTER OR REMOVE
 * COPYRIGHT NOTICES OR THIS HEADER. Copyright 2009, Ben Mazyopa. All rights
 * reserved. The contents of this file are subject to the terms of either the
 * GNU General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License"). You may not
 * use this file except in compliance with the License
 */
package org.idc.upload;

import java.io.File;
import java.io.InputStream;
import java.io.Serializable;
import org.apache.commons.fileupload.FileItem;

public class UploadedFile implements Serializable
{
private static final long serialVersionUID = 3932877942216518622L;
private String            fileName;
private String            contentType;
private long              fileSize;
private String            longFileName;
private String            fileContent;
private InputStream       inputStream      = null;
private String            shortFileName;

public UploadedFile()
{}

public UploadedFile(FileItem fileItem,String longFileName,String shortFileName)
{
   fileName = fileItem.getName();
   contentType = fileItem.getContentType();
   fileSize = fileItem.getSize();
   fileContent = fileItem.getString();
   this.shortFileName = shortFileName;
   this.longFileName = longFileName;
   try
   {
      inputStream = fileItem.getInputStream();
   }
   catch (Exception e)
   {
      System.out.print(e.getMessage());
   }
}

/**
 * Deletes the file
 * 
 * @return
 */
public boolean delete()
{
   File file = new File(longFileName);
   return file.delete();
}

public InputStream getInputStream()
{
   return inputStream;
}

/**
 * @return Returns the orginal name of the uploaded file
 */
public String getFileName()
{
   return fileName;
}

/**
 * Returns the content type for the uploaded file
 * 
 * @return
 */
public String getContentType()
{
   return contentType;
}

/**
 * Returns the size of the file in bytes
 * 
 * @return
 */
public long getFileSize()
{
   return fileSize;
}

/**
 * Returns the abosulute path of the uploaded file
 * 
 * @return
 */
public String getLongFileName()
{
   return longFileName;
}

/**
 * Returns the contents of the file in string form
 * 
 * @return
 */
public String getFileContent()
{
   return fileContent;
}

/**
 * Returns the relative path of the uploaded file
 * 
 * @return
 */
public String getShortFileName()
{
   return shortFileName;
}
}